@@ -1,5 +1,7 @@
 """
-Main interface for fis service literal definitions.
+Type annotations for fis service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/literals.html)
 
 Usage::
 
